@@ -70,6 +70,10 @@ ENTRIES = [
     # plugins
     CE('plugin_search_path', str, '$AM_BUILTIN_PLUGINS:~/.local/share/angr-management/plugins'),
     CE('plugin_blacklist', str, 'sample_plugin'),
+
+    # configurations for individual plugins
+    # TOOD: Move them to separate locations
+    CE('plugin_ComponentsPlugin_enabled', bool, False),
 ]
 
 
